# Security Policy

If you discover a security vulnerability within this project, we encourage you to report it responsibly.

**Please do not open a public issue to report a security vulnerability.**

To report a security issue, please follow these steps:

1. **Navigate to the [Security](https://github.com/spyel/vines/security) tab** in this repository.
2. Click on **"Report a vulnerability"**.
3. Provide as much detail as possible about the vulnerability, including steps to reproduce it, if applicable.

We appreciate your help in keeping this project secure.

Thank you!
